@@ -1,4 +1,5 @@
-#' Budget and/or sample size, power, MDES calculation for two-level multisite randomized trials
+#' Budget and/or sample size, power, MDES calculation for two-level
+#' MRTs detecting main effects
 #'
 #' @description This function can calculate required budget for desired power,
 #'     power or minimum detectable effect size (MDES) under fixed budget
@@ -10,7 +11,7 @@
 #' @inheritParams power.2
 #' @inheritParams power.3m
 #'
-#' @param expr returned objects from function \code{\link{od.2m}}; default is NULL;
+#' @param expr Returned objects from function \code{\link{od.2m}}; default is NULL;
 #'     if \code{expr} is specified, parameter values of \code{icc},
 #'     \code{r12}, \code{r22m},
 #'     \code{c1}, \code{c2},
@@ -20,14 +21,13 @@
 #'     only the values of \code{p} and \code{n} that specified or solved in
 #'     function \code{\link{od.2m}} can be overwritten
 #'     if \code{constraint} is specified.
-#' @param constraint specify the constrained values of \code{p} and/or \code{n}
+#' @param constraint Specify the constrained values of \code{p} and/or \code{n}
 #'     in list format to overwrite those from \code{expr}; default value is NULL.
-#' @param r22m the proportion of variance of site-specific treatment effect explained by covariates.
-#' @param c2 the cost of sampling one level-2 unit.
-#' @param p the proportion of level-1 units to be assigned to treatment.
-#' @param q2 the number of covariates at level 2.
-#' @param q1 the number of covariates at level 1.
-#' @param mlim the range for searching the root of budget (\code{m}) numerically,
+#' @param r22m The proportion of variance of site-specific treatment effect explained by covariates.
+#' @param c2 The cost of sampling one level-2 unit.
+#' @param p The proportion of level-1 units to be assigned to treatment.
+#' @param q The number of covariates at level 2.
+#' @param mlim The range for searching the root of budget (\code{m}) numerically,
 #'     default is the costs sampling \code{Jlim} level-2 units
 #'     or c(4 * Jcost, 1e+10 * Jcost) with Jcost =
 #'     (1 - p) * c1 * n + p * c1t * n + c2.
@@ -40,73 +40,73 @@
 #' @export power.2m
 #'
 #' @references
-#'   Shen, Z. (in progress). Using optimal sample allocation to
-#'   improve statistical precision and design efficiency for multilevel randomized trials
-#'   (Unpublished doctoral dissertation). University of Cincinnati, Cincinnati, OH.
+#'    Shen, Z., & Kelcey, B. (in press). Optimal sample
+#'    allocation in multisite randomized trials. The Journal of Experimental Education.
+#'    <https://doi.org/10.1080/00220973.2020.1830361>
 #'
 #' @examples
-#' # unconstrained optimal design #---------
+#' # Unconstrained optimal design #---------
 #'   myod1 <- od.2m(icc = 0.2, omega = 0.02, r12 = 0.5, r22m = 0.5,
 #'               c1 = 1, c2 = 10, c1t = 10,
 #'               varlim = c(0, 0.005))
-#'   myod1$out # n = 20, p = 0.37
+#'   myod1$out # n = 19.8, p = 0.37
 #'
-#' # ------- power analyses by default considering costs and budget -------
-#' # required budget and sample size
-#'   mym.1 <- power.2m(expr = myod1, d = 0.2, q1 = 1, q2 = 1, power = 0.8)
-#'   mym.1$out  # m = 612, J = 6.3
+#' # ------- Power analyses by default considering costs and budget -------
+#' # Required budget and sample size
+#'   mym.1 <- power.2m(expr = myod1, d = 0.2, q = 1, power = 0.8)
+#'   mym.1$out  # m = 2019, J = 20.9
 #'   # mym.1$par  # parameters and their values used for the function
-#' # or equivalently, specify every argument in the function
-#'   mym.1 <- power.2m(d = 0.2, power = 0.8, q1 = 1, q2 = 1,
+#' # Or, equivalently, specify every argument in the function
+#'   mym.1 <- power.2m(d = 0.2, power = 0.8, q = 1,
 #'                  icc = 0.2, omega = 0.02, r12 = 0.5, r22m = 0.5,
 #'                  c1 = 1, c2 = 10, c1t = 10,
 #'                  n = 20, p = 0.37)
-#' # required budget and sample size with constrained p
-#'   mym.2 <- power.2m(expr = myod1, d = 0.2, q1 = 1, q2 = 1, power = 0.8,
+#' # Required budget and sample size with constrained p
+#'   mym.2 <- power.2m(expr = myod1, d = 0.2, q = 1, power = 0.8,
 #'                  constraint = list(p = 0.5))
-#'   mym.2$out  # m = 726, J = 6.1
-#' # required budget and sample size with constrained p and n
-#'   mym.3 <- power.2m(expr = myod1, d = 0.2, q1 = 1, q2 = 1, power = 0.8,
+#'   mym.2$out  # m = 2373, J = 19.8
+#' # Required budget and sample size with constrained p and n
+#'   mym.3 <- power.2m(expr = myod1, d = 0.2, q = 1, power = 0.8,
 #'                  constraint = list(p = 0.5, n = 5))
-#'   mym.3$out  # m = 702, J = 18.7
+#'   mym.3$out  # m = 2502, J = 66.7
 #'
 #' # Power calculation
-#'   mypower <- power.2m(expr = myod1, q1 = 1, q2 = 1, d = 0.2, m = 612)
+#'   mypower <- power.2m(expr = myod1, q = 1, d = 0.2, m = 2019)
 #'   mypower$out  # power = 0.80
 #' # Power calculation under constrained p (p = 0.5)
-#'   mypower.1 <- power.2m(expr = myod1, q1 = 1, q2 = 1, d = 0.2, m = 612,
+#'   mypower.1 <- power.2m(expr = myod1, q = 1, d = 0.2, m = 2019,
 #'                  constraint = list(p = 0.5))
-#'   mypower.1$out  # power = 0.73
+#'   mypower.1$out  # power = 0.72
 #'
 #' # MDES calculation
-#'   mymdes <- power.2m(expr = myod1, q1 = 1, q2 = 1, power = 0.80, m = 612)
+#'   mymdes <- power.2m(expr = myod1, q = 1, power = 0.80, m = 2019)
 #'   mymdes$out  # d = 0.20
 #'
 #'
-#' # ------- conventional power analyses with cost.model = FALSE-------
+#' # ------- Conventional power analyses with cost.model = FALSE-------
 #' # Required sample size
-#'   myJ <- power.2m(cost.model = FALSE, expr = myod1, d = 0.2, q1 = 1, q2 = 1, power = 0.8)
+#'   myJ <- power.2m(cost.model = FALSE, expr = myod1, d = 0.2, q = 1, power = 0.8)
 #'   myJ$out  # J = 6.3
 #'   # myL$par  # parameters and their values used for the function
-#' # or equivalently, specify every argument in the function
-#'   myJ <- power.2m(cost.model = FALSE, d = 0.2, power = 0.8, q1 = 1, q2 = 1,
+#' # Or, equivalently, specify every argument in the function
+#'   myJ <- power.2m(cost.model = FALSE, d = 0.2, power = 0.8, q = 1,
 #'                  icc = 0.2, omega = 0.02, r12 = 0.5, r22m = 0.5,
 #'                  c1 = 1, c2 = 10, c1t = 10,
 #'                  n = 20, p = 0.37)
 #'
 #' # Power calculation
-#'   mypower1 <- power.2m(cost.model = FALSE, expr = myod1, J = 6.3, d = 0.2, q1 = 1, q2 = 1)
+#'   mypower1 <- power.2m(cost.model = FALSE, expr = myod1, J = 6.3, d = 0.2, q = 1)
 #'   mypower1$out  # power = 0.80
 #'
 #' # MDES calculation
-#'   mymdes1 <- power.2m(cost.model = FALSE, expr = myod1, J = 6.3, power = 0.8, q1 = 1, q2 = 1)
+#'   mymdes1 <- power.2m(cost.model = FALSE, expr = myod1, J = 6.3, power = 0.8, q = 1)
 #'   mymdes1$out  # d = 0.20
 #'
 power.2m <- function(cost.model = TRUE, expr = NULL, constraint = NULL,
                     sig.level = 0.05, two.tailed = TRUE,
                     d = NULL, power = NULL, m = NULL,
                     n = NULL, J = NULL, p = NULL,
-                    icc = NULL, r12 = NULL, r22m = NULL, q1  = NULL, q2  = NULL,
+                    icc = NULL, r12 = NULL, r22m = NULL, q  = NULL,
                     c1 = NULL, c2 = NULL, c1t = NULL,  omega = NULL,
                     dlim = NULL, powerlim = NULL, Jlim = NULL, mlim = NULL,
                     rounded = TRUE) {
@@ -185,10 +185,8 @@ power.2m <- function(cost.model = TRUE, expr = NULL, constraint = NULL,
     if (NumberCheck(m))
       stop("'m' must be numeric in [0, Inf)")
   }
-  if (NumberCheck(q1 ) | q1  < 0)
-    stop("'q1' must be numeric with q1  >= 0")
-  if (NumberCheck(q2 ) | q2  < 0)
-    stop("'q2' must be numeric with q2  >= 0")
+  if (NumberCheck(q ) | q  < 0)
+    stop("'q' must be numeric with q  >= 0")
   if (NumberCheck(n) || n <= 0)
     stop("'n' must be numeric with n > 0")
   if (NumberCheck(d) || any(0 > d | d > 5))
@@ -198,7 +196,7 @@ power.2m <- function(cost.model = TRUE, expr = NULL, constraint = NULL,
               two.tailed = two.tailed, d = d, icc = icc,
               r12 = r12, r22m = r22m, c1 = c1, c2 = c2,
               c1t = c1t, omega = omega, n = n, p = p,
-              q1  = q1, q2 = q2, m = m, power = power)
+              q = q, m = m, power = power)
   tside <- ifelse(two.tailed == TRUE, 2, 1)
   if (cost.model == TRUE) {
     Jcost <- ((1 - p) * c1 * n +  p * c1t * n + c2)
@@ -207,18 +205,18 @@ power.2m <- function(cost.model = TRUE, expr = NULL, constraint = NULL,
         J <- m / ((1 - p) * c1 * n +  p * c1t * n + c2);
         lambda <- d * sqrt((p * (1 - p) * n * m / ((1 - p) * c1 * n +  p * c1t * n + c2)) /
           (p * (1 - p) * n * omega * (1 - r22m) + (1 - icc) * (1 - r12)));
-        1 - pt(qt(1 - sig.level / tside, df = (J - q2 - 1) * (n - q1 - 2)),
-               df = (J - q2 - 1) * (n - q1 - 2), lambda) +
-          pt(qt(sig.level / tside, df = (J - q2 - 1) * (n - q1 - 2)),
-             df = (J - q2 - 1) * (n - q1 - 2), lambda)
+        1 - pt(qt(1 - sig.level / tside, df = J - q - 1),
+               df = J - q - 1, lambda) +
+          pt(qt(sig.level / tside, df = J - q - 1),
+             df = J - q - 1, lambda)
       })
     } else {
       pwr.expr <- quote({
         J <- m / ((1 - p) * c1 * n +  p * c1t * n + c2);
         lambda <- d * sqrt((p * (1 - p) * n * m / ((1 - p) * c1 * n +  p * c1t * n + c2)) /
                              (p * (1 - p) * n * omega * (1 - r22m) + (1 - icc) * (1 - r12)));
-        1 - pt(qt(1 - sig.level / tside, (J - q2 - 1) * (n - q1 - 2)),
-               df = (J - q2 - 1) * (n - q1 - 2), lambda)
+        1 - pt(qt(1 - sig.level / tside, J - q - 1),
+               df = J - q - 1, lambda)
       })
     }
   } else {
@@ -226,17 +224,17 @@ power.2m <- function(cost.model = TRUE, expr = NULL, constraint = NULL,
       pwr.expr <- quote({
         lambda <- d * sqrt((p * (1 - p) * n * J) /
                              (p * (1 - p) * n * omega * (1 - r22m) + (1 - icc) * (1 - r12)));
-        1 - pt(qt(1 - sig.level / tside, df = (J - q2 - 1) * (n - q1 - 2)),
-               df = (J - q2 - 1) * (n - q1 - 2), lambda) +
-          pt(qt(sig.level / tside, df = (J - q2 - 1) * (n - q1 - 2)),
-             df = (J - q2 - 1) * (n - q1 - 2), lambda)
+        1 - pt(qt(1 - sig.level / tside, df = J - q - 1),
+               df = J - q - 1, lambda) +
+          pt(qt(sig.level / tside, df = J - q - 1),
+             df = J - q - 1, lambda)
       })
     } else {
       pwr.expr <- quote({
         lambda <- d * sqrt((p * (1 - p) * n * J) /
                              (p * (1 - p) * n * omega * (1 - r22m) + (1 - icc) * (1 - r12)));
-        1 - pt(qt(1 - sig.level / tside, (J - q2 - 1) * (n - q1 - 2)),
-               df = (J - q2 - 1) * (n - q1 - 2), lambda)
+        1 - pt(qt(1 - sig.level / tside, J - q - 1),
+               df = J - q - 1, lambda)
       })
     }
   }
